#
# spec file for package wxMaxima
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Tests fail on chroot, but work fine locally
# https://github.com/wxMaxima-developers/wxmaxima/issues/1699
%bcond_with tests
%define X_display ":98"
%define __builder ninja
%define tarname wxmaxima
Name:           wxMaxima
Version:        24.02.0
Release:        1.1
Summary:        Graphical User Interface for the maxima Computer Algebra System
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://wxmaxima-developers.github.io/wxmaxima/
Source0:        https://github.com/wxmaxima-developers/wxmaxima/archive/Version-%{version}.tar.gz#/%{tarname}-Version-%{version}.tar.gz
BuildRequires:  cmake >= 3.10
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  hicolor-icon-theme
BuildRequires:  maxima >= 5.30.0
BuildRequires:  maxima-exec-sbcl
BuildRequires:  ninja
BuildRequires:  po4a
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-devel >= 3.1.5
# gnuplot is needed for plotting
Requires:       gnuplot
Requires:       maxima >= 5.30.0
Recommends:     %{name}-lang
# SECTION For tests
%if %{with tests}
BuildRequires:  appstream-glib
BuildRequires:  xvfb-run
%endif
# /SECTION
ExcludeArch:    ppc64 ppc64le

%lang_package

%description
wxMaxima is a GUI for the computer algebra system maxima
based on wxWidgets.

%prep
%autosetup -p1 -n %{tarname}-Version-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install
# INSTALL HI-RES ICONS GENERATED OUT OF UPSTREAM SVG ICON
for i in 24 32 48 64 128 256 512
do
  rsvg-convert -w ${i} data/io.github.wxmaxima_developers.wxMaxima.svg -o wxmaxima-${i}.png
  install -D -m 0644 wxmaxima-${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/io.github.wxmaxima_developers.wxMaxima.png
  rsvg-convert -w ${i} data/text-x-wxmathml.svg -o text-x-wxmathml-${i}.png
  install -D -m 0644 text-x-wxmathml-${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/mimetypes/text-x-wxmathml.png
  rsvg-convert -w ${i} data/text-x-wxmaxima-batch.svg -o text-x-wxmaxima-batch-${i}.png
  install -D -m 0644 text-x-wxmaxima-batch-${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/mimetypes/text-x-wxmaxima-batch.png
done
install -D -m 0644 data/io.github.wxmaxima_developers.wxMaxima.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/io.github.wxmaxima_developers.wxMaxima.svg
install -D -m 0644 data/text-x-wxmathml.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/mimetypes/text-x-wxmathml.svg
install -D -m 0644 data/text-x-wxmaxima-batch.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/mimetypes/text-x-wxmaxima-batch.svg

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/mimetypes

# REMOVE UNNECESSARY ICONS OUT OF PIXMAPS
rm %{buildroot}%{_datadir}/pixmaps/*

# Remove license installed by make install, we include them by using %%license
rm %{buildroot}%{_datadir}/doc/%{tarname}/{COPYING,GPL.txt}

%suse_update_desktop_file io.github.wxmaxima_developers.wxMaxima
%fdupes %{buildroot}%{_prefix}
%find_lang %{name} %{?no_lang_C}

%if %{with tests}
%check
# Needed, otherwise maxima tries to write to a dir without permissions
export MAXIMA_USERDIR=./
pushd ./%{__builddir}
xvfb-run ctest --output-on-failure --force-new-ctest-process %{?_smp_mflags}
popd
%endif

%post
%install_info --info-dir=%{_infodir} %{_infodir}/wxmaxima.info%{ext_info}

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/wxmaxima.info%{ext_info}

%files
%license COPYING GPL.txt
%doc %{_datadir}/doc/%{tarname}/
%{_bindir}/*
%{_datadir}/wxMaxima/
%{_datadir}/icons/hicolor/*/apps/io.github.wxmaxima_developers.wxMaxima.*
%{_datadir}/icons/hicolor/*/mimetypes/*
%{_datadir}/applications/*.desktop
%{_datadir}/bash-completion/completions/wxmaxima
%{_datadir}/metainfo/*.appdata.xml
%{_mandir}/man1/wxmaxima*%{ext_man}
%{_mandir}/*/man1/wxmaxima*%{ext_man}
%{_datadir}/mime/packages/*.xml

%files lang -f %{name}.lang

%changelog
* Mon Feb  5 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 24.02.0:
  * Faster start-up
  * Better performance directly after startup
  * Faster loading of files
  * Better button placement in sidebars
  * Got rid of a crash on startup in fedora
    (gh#wxmaxima-developers/wxmaxima#1862)
  * Clear wxMaxima's input buffer on starting a new maxima process
    (gh#wxmaxima-developers/wxmaxima#1856)
  * A nicer ChangeLog dialogue
  * Corrected for swapped row and columns in wizard enter matrix
  * Fixed a few bugs in the XML saving code
    (gh#wxmaxima-developers/wxmaxima#1867)
  * Zooming did cause recalculation only for the 1st cell
    (gh#wxmaxima-developers/wxmaxima#1870)
  * Many config changes now have immediately effect on the
    worksheet
  * Added the unicode-enhanced ASCII art from maxima to the menus
  * Steamlined the cell size calculation stuff
  * Completely overhauled the printing functionality
  * Moved more of the help file indexing to the background
    (gh#wxmaxima-developers/wxmaxima#1856)
  * Better event handling in the unicode sidebars
    (gh#wxmaxima-developers/wxmaxima#1875, #1863)
  * Reading out the values of maxima variables for the GUI was
    broken
  * Many checkmarks in menus had the wrong value
  * Maxima's demos are now available in the menu and context menu
  * Default the filter search boxes to text search, not regex
  * Rescaling affected size calculations for code only with a
    delay
  * Mac Os: way higher stability if multiple windows are open
  * The context menu in the "greek letters" sidebar now works
    (gh#wxmaxima-developers/wxmaxima#1878)
  * Resolved an assert if the internal help browser was disabled,
  * but requested (gh#wxmaxima-developers/wxmaxima#1881)
  * wxMaxima now preserves history entries between sessions
  * Better LibreOffice compatibility with the MathML output
  * Better HTML output
  * Fix crash when exporting a worksheet with animations to TeX
  * Resolved a crash on closing a window
    (gh#wxmaxima-developers/wxmaxima#1889)
* Mon Dec 25 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.12.0:
  * Input text selection was cleared when right-clicking on it
    (gh#wxMaxima-developers/wxmaxima#1845).
  * Pressing both mouse buttons simultaneously caused an assert
    (gh#wxMaxima-developers/wxmaxima#1844).
  * Corrected the cursor position after unsuccessful
    autocompletes.
  * Corrected the handling of question prompts from maxima
    (gh#wxMaxima-developers/wxmaxima#1827).
  * Bug corrections in the search functionality.
  * RegEx search works again.
  * Clicking on the notification now is more likely to focus the
    worksheet.
  * Corrected the cell folding logic
    (gh#wxMaxima-developers/wxmaxima#1853).
  * Folded cells are no more evaluated
    (gh#wxMaxima-developers/wxmaxima#1853).
  * Now we try to generate a backtrace on crashes
    (gh#wxMaxima-developers/wxmaxima#1802).
  * Corrected the position of integral limits.
  * Nicer product, sum and integral signs.
  * Hidden cells weren't restored from wxm files
    (gh#wxMaxima-developers/wxmaxima#1855).
  * diff() no longer causes spurious multiplication dots
    (gh#wxMaxima-developers/wxmaxima#1825).
* Mon Nov 20 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.11.0:
  * Correctly draw the bracket of the cell under the cursor
    (gh#wxMaxima-developers/wxmaxima#1811).
  * Maths display was corrupted if the window was temporarily not
    wide enough to display it in 2D
    (gh#wxMaxima-developers/wxmaxima#1812).
  * Added many range checks to the code.
  * Correct label scaling after changing the zoom factor
    (gh#wxMaxima-developers/wxmaxima#1815).
  * Repaired "copy as bitmap"
    (gh#wxMaxima-developers/wxmaxima#1820).
  * Repaired EMF and SVG output
    (gh#wxMaxima-developers/wxmaxima#1838).
  * Focus the search text on activating the search box
    (gh#wxMaxima-developers/wxmaxima#1821).
  * Correctly support dropping multiple files on the worksheet.
  * If the worksheet isn't empty dropping a file on the worksheet
    no more closes the currently open file.
  * Try harder to kill maxima on closing it
    (gh#wxMaxima-developers/wxmaxima#1824).
  * Menu items for displaying the internal representation.
  * Better display of diff(), if multiplication dots are enabled
    (gh#wxMaxima-developers/wxmaxima#1825).
  * Tried to resolve a few asserts
    (gh#wxMaxima-developers/wxmaxima#1831).
  * Resolved many warnings from several static analysis tools.
  * Fine-tuning of the "undo" function.
* Sun Oct  8 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.10.0:
  * A big rewrite to make the static analysis tools happy.
  * Many stability improvements.
  * Maxima's help commands work again out-of-the-box.
  * Corrected the worksheet size calculation.
  * Better support for loading .wxmx files from weird paths.
  * Finally resolved the "Right-click resets zoom" problem
    (gh#wxMaxima-developers/wxmaxima#1810).
  * A speed up.
  * Many right-click menu fixes
    (gh#wxMaxima-developers/wxmaxima#1810).
  * Display/Hide label fixes.
  * Many help browser improvements
    (gh#wxMaxima-developers/wxmaxima#1802).
  * The worksheet size no more is underestimated
    (gh#wxMaxima-developers/wxmaxima#1802).
  * Cell creation fixes.
  * Copy-and-paste improvements
    (gh#wxMaxima-developers/wxmaxima#1809).
  * Better error messages for bitmaps.
  * Many additional bug fixes.
* Thu Sep  7 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.8.0:
  * Better print scaling.
  * More consistent page size handling for printing.
  * Many performance and stability fixes from coverity-scan.
  * Resolved many warnings from cppcheck.
  * A RegEx search.
* Wed Aug  2 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.7.0:
  * Printing:
  * Made the page margins configurable
    (gh#wxMaxima-developers/wxmaxima#1787).
  * We no more print page headers
    (gh#wxMaxima-developers/wxmaxima#1791).
  * Printing no more omits labels
    (gh#wxMaxima-developers/wxmaxima#1507).
  * A better pagebreak algorithm.
  * No more ghost lines around text cells.
  * Less ugly integral signs.
  * Many stability fixes.
  * More Consistent worksheet scaling and sizes
    (gh#wxMaxima-developers/wxmaxima#1780).
  * Correctly save the color settings
    (gh#wxMaxima-developers/wxmaxima#1789).
  * Correctly check the numeric and other menu items.
  * The cursor no more disappears
    (gh#wxMaxima-developers/wxmaxima#1788).
  * Updated translations.
* Sat Jun 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.5.1:
  * Process the command line option --maxima=.
  * Resolved several possibilities to crash the config dialogue
    (gh#wxMaxima-developers/wxmaxima#1774,
    gh#wxMaxima-developers/wxmaxima#1766).
  * Correctly calculate the worksheet size in the background
    (gh#wxMaxima-developers/wxmaxima#1766).
  * Correctly restore parenthesis on load
    (gh#wxMaxima-developers/wxmaxima#1779).
  * Always revise the decision what to display as 2D equation on
    window width changes.
  * 2D display of integrals had zero size
    (gh#wxMaxima-developers/wxmaxima#1780).
* Thu May 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.5.0:
  * Got rid of some compiler and cppcheck warnings.
  * Big performance improvements.
  * A "maxima versus typical programming languages" tutorial.
  * Table of contents: Jump to the chapter the cursor is in.
  * Resolved another crash in the config dialogue.
  * Updated the unicode character list.
  * Resolved more potential event ID clashes.
  * Use an external file as wxMathML.lisp is now selected using a
    command line option, not configured in the GUI. This is mostly
    needed for developers, no need to expose it to the end user.
  * Better handling of paths to maxima when starting new wxMaxima
    processes.
  * new wxMaxima processes now get more of the command-line args
    of the parent process.
  * wxMaxima no more tries to install its own fonts.
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.4.1:
  * More config dialogue tweaks.
  * Recent file list: Don't try to re-use no-more-used wxWidgets
    IDs.
  * Make sure that the help sidebar is shown when opening a help
    topic.
  * If maxima wants us to open a help browser and wxMaxima was
    compiled without one it now opens an external help browser.
  * The load() command now again works with symbols as package
    names..
- Changes from version 23.4.0:
  * Made the GUI more responsive for functions with much output.
  * Handle errors in the XML from maxima more gracefully.
  * Rewrote parts of the lisp part of wxMaxima.
  * Resolved a few lisp warnings.
  * Resolved a few XML errors caused by not escaping special
    chars.
  * Automatic XML generation tests.
  * Correct display of operators.
  * A better style sample for the config dialogue.
  * Resolved several asserts.
  * Resolved a few small bugs in the autosave logic.
* Tue Mar 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.3.0:
  * More styles consistency
    (gh#wxMaxima-developers/wxmaxima#1753).
  * Better configuration validation
  * Depending on the wxWidgets version Unicode letters were
    interpreted inorrectly (gh#wxMaxima-developers/wxmaxima#1754).
  * The manual anchors cache now saves the file-per-chapter URLs,
    too.
  * cmake -DWXM_DISABLE_WEBVIEW now allows to find wxWidgets, if
    wxWebView wasn't compiled.
  * Completely rewrote the dockable-sidebars-stuff.
  * Many files are now build on demand, not at configure time.
* Tue Feb 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23.2.0:
  * Fix XML generation of wxmx documents
    (gh#wxMaxima-developers/wxmaxima#1556).
  * A faster font cache.
  * Faster communication between wxMaxima and maxima.
  * Dropped the dependency on an [internal] ww898 library.
  * More consistent text style handling.
  * A separate style for operators
    (gh#wxMaxima-developers/wxmaxima#1002).
  * A nicer ChangeLog.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 22.12.0:
  * A cleaner status bar with double-click actions
  * Better display of labels
  * box() now is displayed as a box, as the maxima manual states
  * box(expr, "highlight") display expr in red, instead
  * Resolved a few display glitches
  * Resolved OS-dependant wrong actions on gui events
  * A few system and compiler specific fixes
  * Resolved a few compilation warnings
  * Try harder to connect maxima if one communication port is blocked
  * Better display of help text in the console
  * Faster saving of .wxmx files
  * Better toolbar bitmap handling
* Mon Dec  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 22.11.1:
  * Repaired zooming the worksheet.
- Changes from version 22.11.0:
  * Resolved an ID collision
    (gh#wxMaxima-developers/wxmaxima#1726).
  * Faster restart of maxima
    (gh#wxMaxima-developers/wxmaxima#1715).
  * Make various dialogs window-modal
    (gh#wxMaxima-developers/wxmaxima#1712).
  * Proper handling of unicode in selection
    (gh#wxMaxima-developers/wxmaxima#1726).
  * An unicode conversion error
    (gh#wxMaxima-developers/wxmaxima#1727).
  * Repaired the "enter matrix" dialogue.
  * Jump to the correct anchor even if using online help.
  * Translation updates.
  * Many windows build improvements.
  * Resolved a crash on restarting maxima.
- Relax wxGTK3 requirement to version >= 3.1.5.
- Use xvfb-run for tests (which still do not work).
* Thu Nov 10 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update BuildRequires: wxGTK >= 3.2 now required.
* Fri Sep  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 22.09.0:
  * Support for wxWidgets 3.1.7
  * The description field for wizards no more is a
    MouseOverToolTip
  * Wizards now accept chars from the unicode buttons
  * Wizards now can balance parenthesis
  * Wizards for operatingsystem, basic programming and string
    operations
  * More miscellaneous work on the wizards
  * The watchlist was broken
  * Better scalability of the config dialogue
  * Folded multiline code cells are now sent to Maxima correctly
    (gh#wxMaxima-developers/wxmaxima#1674)
  * The output of the "?" command contained spurious "<"
    (gh#wxMaxima-developers/wxmaxima#1688)
  * ?, ?? and describe() now use a browser window, by default
  * Search harder for the Maxima manual
  * Search harder for Maxima manual entries
  * Now we find Maxima manual entries that have no explicit anchor
  * On Linux, MacOs and, if wxWidgets was compiled with edge
    support the help browser can be obened in a dockable window
  * wxMaxima can now compiled, even if wxWidgets was configured
    with the option "--enable-privatefonts=no".
  * Names that end in an underscore are now printed correctly
    (gh#wxMaxima-developers/wxmaxima#1706)
  * Made the tests work on more platforms
    (gh#wxMaxima-developers/wxmaxima#1709)
  * Resolved some asserts (gh#wxMaxima-developers/wxmaxima#1574)
  * Working MathJaX (gh#wxMaxima-developers/wxmaxima#1702)
  * A primitive integrated ChangeLog viewer
  * Better documentation (gh#wxMaxima-developers/wxmaxima#1693)
  * Better unicode handling (gh#wxMaxima-developers/wxmaxima#1691)
  * Many additional bugfixes
- Drop wxMaxima-disable-slow-multithreadtest.patch: Incorporated
  upstream.
* Fri Jul 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 22.05.0:
  * Added guess_exact_value to the numeric menu.
  * Added lapack to the matrix menu.
  * Added linpack to the numeric menu.
  * Added a "declare facts" right-click menu entry to variables.
  * We no more reserve space for hidden input.
  * A better logexpand section in the numeric menu.
  * Many wizards have a more modern look and feel, now.
  * The modern-style wizards are now dockable by default.
  * Undo and redo buttons for the toolbar.
  * A "construct fraction" wizard
    (gh#wxMaxima-developers/wxmaxima#1664).
  * Printing multiple-page documents now should work again on
    Linux (gh#wxMaxima-developers/wxmaxima#1671).
  * The selection should now no more overwrite test
    (gh#wxMaxima-developers/wxmaxima#1665).
  * Hidden code cells now are correctly sent to maxime
    (gh#wxMaxima-developers/wxmaxima#1674).
  * Support for wxWidgets 3.1.6.
- Disable testing until issues sorted
  (gh#wxMaxima-developers/wxmaxima#1699).
* Sat Apr 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 22.04.0:
  * Resolved a bug in parenthesis matching
    (gh#wxMaxima-developers/wxmaxima#1649).
  * Faster startup logic.
  * Translation updates.
* Sat Mar 26 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 22.03.0:
  * Add an compile option "WXM_INCLUDE_FONTS", which allows to
    specify, if additional fonts should be included.
  * Rename command line option --logtostdout to --logtostderr.
  * A better heuristics for finding out what to style as 1D maths.
  * Consistent image resolutions.
  * No more crashes on exporting multiple animations at once
    [gh#wxMaxima-developers/wxmaxima#1616].
  * Drag-and-Drop in the table of contents
  * Table of contents: Convert sections to subsections and similar
    [gh#wxMaxima-developers/wxmaxima#1629].
  * Parenthesis and quote matching now uses the maxima parser.
  * A way of limiting the toc depth shown in the table of
    contents.
  * Now the problems after a kill(all) should be finally resolved.
  * Better support for the debugger
    [gh#wxMaxima-developers/wxmaxima#1625].
  * Machine-Float NaNs no more causes XML errors.
  * Labels with hexadecimal numbers no more cause crashes
    [gh#wxMaxima-developers/wxmaxima#1633].
  * wxMaxima no more skips chars in subscripted variables
    [gh#wxMaxima-developers/wxmaxima#1632].
  * Merging cells per keyboard shortcut works again
    [gh#wxMaxima-developers/wxmaxima#1626].
  * Symbols buttons whose symbols the GUI font lacks are now
    hidden.
- Minor rebase of wxMaxima-disable-slow-multithreadtest.patch to
  apply cleanly.
* Tue Dec  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21.11.0:
  * Allow seeing all files in the file save dialog
    (gh#wxMaxima-developers/wxmaxima#1557).
  * Fix an error when using Alt up arrow (show previous command)
    (gh#wxMaxima-developers/wxmaxima#1566).
  * Rewrote a config dialogue.
  * Improvements in the manual.
  * Fix a warning, which occurred, when starting wxMaxima the
    first time.
  * ww898 unnecessarily limited the list of supported platforms.
  * wxMaxima's properties to Maxima symbols can now no more be
    killed.
  * Allow single GroupCells to be converted to LaTeX.
  * Enable reloading and changing images inserted via "Cell" ->
    "Insert Image..." (gh#wxMaxima-developers/wxmaxima#1597).
  * Correctly set the document saved state when the size of an
    image is changed.
  * Use the AUTHORS file for the Credits page in the "About"
    dialogue.
  * Handle power events (gh#wxMaxima-developers/wxmaxima#1607).
  * Fix ugly buttons in the sidebars with recent wxWidgets.
  * Updated translations.
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 21.05.2
  * Source cleanup, no visible changes for Linux users
- Provide correct documentation files
* Tue May 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21.05.1:
  * Resolved a segfault on printing that could be triggered on
    some computers.
- Changes from version 21.05.0:
  * Long numbers now can be broken into lines.
  * On Export long numbers sometimes got lost.
  * The height of folded cells now is calculated correctly, again
    (gh#wxMaxima-developers/wxmaxima#1532).
  * Printing now can insert pagebreaks within GroupCells
    (gh#wxMaxima-developers/wxmaxima#970,
    gh#wxMaxima-developers/wxmaxima#1528,
    gh#wxMaxima-developers/wxmaxima#1241,
    gh#wxMaxima-developers/wxmaxima#181,
    gh#wxMaxima-developers/wxmaxima#573,
    gh#wxMaxima-developers/wxmaxima#1082).
  * Changed the font for the PDF manuals to free Google Noto
    fonts.
  * Now all PDF manuals can be created without missing characters.
  * Solved a crash when printing.
  * Updated translations.
* Tue May  4 2021 Dirk Müller <dmueller@suse.com>
- remove pandoc dependency (seems to build without and is not available
  on 32bit platforms)
* Tue Apr 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21.04.0:
  * Fix visualization after "Evaluate all cells (Ctrl+Shift+R)"
    (gh#wxMaxima-developers/wxmaxima#1512).
  * Fix context sensitive help with F1
    (gh#wxMaxima-developers/wxmaxima#1508).
  * Add an option for not showing matching parenthesis
    (gh#wxMaxima-developers/wxmaxima#1509).
  * Changed the weather icons in the toolbar to more meaningful
    ones (gh#wxMaxima-developers/wxmaxima#1514).
  * Many bugfixes with respect to correctly breaking lines
    (gh#wxMaxima-developers/wxmaxima#1528,
    gh#wxMaxima-developers/wxmaxima#1471,
    gh#wxMaxima-developers/wxmaxima#1512).
  * Fix a bug in copy-paste of saved/loaded results
    (gh#wxMaxima-developers/wxmaxima#1518).
  * Fix a crash when pressing Ctrl-X while a math cell is selected
    (gh#wxMaxima-developers/wxmaxima#1519).
  * CMake 3.10 is now required for building wxMaxima.
  * C++ 14 is required for building wxMaxima. Now CMake knows
    about that fact.
  * Many external build scripts are now replaced by C++ and CMake
    commands.
  * A menu entry for when to invoke the debugger.
* Thu Mar  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21.02.0:
  * Replaced openMP by c++11's built-in thread handling.
  * Resolved a crash when deleting regions.
  * The --ini switch should work again correctly.
  * Fix an issue, where demos didn't re-center screen anymore,
    when screen is full and print was incomplete.
  * Made the time between autosaves configurable.
  * Fixed an issue with reproducible builds.
  * Updated translations.
- Add upstream bug reference [gh#wxMaxima-developers/wxmaxim#1504]
  for wxMaxima-disable-slow-multithreadtest.patch and change
  PATCH-FIX-OPENSUSE tag to PATCH-FIX-UPSTREAM.
* Sat Feb 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21.01.0:
  * Many small bugfixes including a crash on loading files with
    images
  * Updated translations.
- Add wxMaxima-disable-slow-multithreadtest.patch: Disable a slow
  test that causes timeouts on OBS workers for openSUSE >= 1550.
* Wed Dec 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.12.2:
  * Compilation now works again in the case that wxWidgets uses
    the stl.
  * Additional eye candy: Nicer display of sets.
- Changes from version 20.12.1:
  * Resolve a small privacy issue.
- Changes from version 20.12.0:
  * Support for gcc 5.5.
  * Many code cleanups.
  * wxMaxima now will work even if no english locale is installed.
  * A few additional bug fixes.
  * More work on a modern look-and-feel.
  * Updated translations.
* Tue Nov 24 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.11.1:
  * Bugfixes and a fight against bit rot in external frameworks.
  * Many bug fixes in various places.
  * Work on a more modern look-and-feel.
  * stringdisp support and a menu item for it.
  * Updated the default MathJAX to version 3.
  * Many autosubscripting improvements.
  * Updated translations.
- Changes from version 20.11.0:
  * Many bug fixes.
  * An editor for maxima's environment variables.
  * Updated translations.
- Run tests as part of %%check section; BuildRequires Xvfb.
* Wed Oct 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add BuildRequires: maxima-exec-sbcl; needed to resolve
  unresolvable status from multiple maxima_exec being available
  after we started building both sbcl and clisp versions of
  maxima.
* Sat Sep 12 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.09.0:
  * Repaired the non-case-sensitive "Replace All" functionality.
  * More efficient and accurate calculation of worksheet object
    sizes.
  * (Hopefully) reduced the last visual glitches.
  * diff cells can now be broken into lines.
  * Another massive performance update.
  * Reduced the memory footprint of big equations.
  * A better 2D ASCII Art mode.
  * Better High-DPI support.
  * If it is configurable it now might have a right-click menu.
  * Reduced the memory footprint of cells used only when line
    breaking is performed.
  * Subscripts created by derivabbrev are now correctly copied as
    "diff" command.
  * If Maxima comes without suitable manual we now use the online
    one instead.
  * Added buttons that reset the configuration.
  * A few menu items now are checkboxes set and cleared by maxima.
  * wxMaxima forgot to release the communication port it used for
    talking to maxima.
  * Improved performance of receiving data from maxima.
  * The font sizes are stored in configuration with full
    precision, without rounding to integer.
  * Many additional bug fixes.
  * Updated translations.
* Wed Jul 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.07.0:
  * A massive performance update.
  * Better display of sqrt() cells.
  * Better display of fractions.
  * Nicer display of lists.
  * Made sure we read in the whole .mac file when opening .mac
    files.
  * Allow building wxMaxima, if pandoc or po4translate are not
    installed.
  * As always many small additional bug fixes.
  * Updated translations.
- Drop wxMaxima-string-type-conversion.patch: upstreamed.
* Sun Jul 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Compile against the more recent toolkit wxGTK3 >= 3.1 for
  openSUSE >= 1550 (mainly for better HiDPI support).
* Fri Jul  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.06.6:
  * Resolved a compiling problem the last release has introduced.
- Changes from version 20.06.1 through 20.06.5: Minor bug fixes.
- Changes from version 20.06.0:
  * Many spell corrections and bugfixes
  * The history sidebar now works again
  * TextCells with copy-alt-text caused an crash
  * A few additional small bugfixes
  * Many (really many!) big stability improvements
  * In sqrt(conjugate(f(x))) the horizontal lines coincided
  * Strings were searched for comment starts when adding line
    endings
  * Faster start-up by avoiding unneeded redraw events
  * A big number of performance improvements
  * Unfortunately one last temporary fix reduces performance again
  * Corrected a bug that sometimes caused parts of equations not
    to be displayed
  * As this allows to improve performance and stability C++14 is
    now used
  * Speed boost The list of anchors from the manual is now cached
    on disk
  * Updated translations.
- Add wxMaxima-string-type-conversion.patch: Fix an invalid
  conversion from wxString to wxChar*
  (gh#wxMaxima-developers/wxmaxima#1324).
- Add new BuildRequires: pandoc.
- Use ninja for build (BuildRequires: ninja).
* Thu May 21 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Remove unused libomp7-devel dependency: when compiling with GCC,
  the GNU implementation libgomp is used, not LLVM's libomp.
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.04.0:
  * Resolved a crash on right-clicking a GroupCell.
  * View/Invert worksheet brightness now toggles an instant dark worksheet mode.
  * Removed an unnecessary info dialogue on startup.
  * Right-click-suggestions for similar command names.
  * Corrected the initial slideshow size.
  * A more stable language selection mechanism.
  * Extended the "fitting data" example.
  * A example on how to iterate through lists efficiently.
  * Many spelling corrections and better formulations.
  * A big number of small bug-fixes.
  * Another noticeable SpeedUp.
  * Updated translations.
* Fri Mar 27 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.03.1:
  * Resolved a crash on right-clicking a GroupCell.
  * Help works again in the german translation.
  * Removed an unnecessary info dialogue on startup.
  * Right-click-suggestions for similar command names.
* Fri Mar 13 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.03.0:
  * Corrected a few last bugs for pre- and post- super- and
    subscripts
  * Many improvements to the manpage and the html documentation
  * Improved support for pre- and post- super- and subscripts
    provided by Robert Dodier
  * wxWidget's integrated help browser on some platforms was
    broken => now the default web browser is used
  * Support for importing static and some types of animated gif
    files
  * Animation frames created using draw() now can be popped out
    interactively
  * A option to configure the max amount of gnuplot data to save
    for this feature
  * wxMaxima now no more crashes on FreeBSD
  * wxMaxima now tries not to use stderr as stderr on the mac
    breaks communication with maxima.
  * Many additional bugfixes.
* Thu Feb 20 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.02.1:
  * wxMaxima now can use Multi-threading, if a new enough OpenMP
    is found
  * Part of the added performance is only effective if omp.h
    (often in the libomp package) is installed.
  * Better scroll wheel support
  * It was possible that a part of a fraction wasn't displayed
  * Several additional bug fixes
  * Cppcheck code analysis now is only run if explicitly enabled
  * The minimum cmake version now is 3.7
  * Translation updates.
- Use %%{name}-%%{version} for source tarball.
- Split out separate -lang package.
- Convert and install mimetype icons to hicolor icon dir.
- New BuildRequires:
  * libomp7-devel (also Requires): enable parallel processing for
    wxmaxima.
  * po4a: for updated translations.
  * graphviz: to generate updated figures in doc.
  * appstream-glib: for validating metainfo file.
- Drop conditionals in post(un) scriptlets for EOL openSUSE
  versions.
- Don't take ownership of system directories in hicolor icon dir
  and metainfo dir.
- Drop rpmlintrc file: no longer applicable.
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Tue Jan 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.01.3:
  * Language selection now works even on system with missing
    language support.
  * Resolved a copy-and-paste regression.
  * Improved stability of the communication with maxima.
  * Preparation for maxima's pre-sub-and supscript feature.
  * Corrected a few visual glitches of the worksheet.
  * More tutorials describing a few of maxima's features.
  * Translation updates.
- Changes from version 20.01.2:
  * Corrected html export of the lowest sectioning unit.
  * Sometimes text after fractions wasn't displayed.
  * Copy-and-paste should now work in more cases.
  * Selecting text within fractions should now work again.
  * Corrected a few display glitches of the worksheet.
  * wxMaxima now comes with five example files.
  * More and better-working mouse-over tooltips.
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20.01.1:
  * Nice menu icons for the operating systems that support this.
  * Started to bundle small tutorials with wxMaxima.
  * Many small additional bug fixes.
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Wed Oct 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 19.10.0:
  * Corrected a Regression: The better display of exponents failed
    for exp(x^2).
  * Updated translations.
* Wed Sep 11 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 19.09.0:
  * Handle timeouts when writing to maxima and partial writes.
  * Worksheet text disappeared on scrolling on some platforms.
  * Sped up sending code to maxima.
  * Removed quoting of Unicode characters within strings sent to
    maxima.
* Wed Aug 21 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 19.08.1
  * Bugfixes for nearly every instance something was drawn on the
    screen.
  * Better handling of multi-cell lisp code.
- Changes from version 19.08.0:
  * More and better test cases.
  * Another SpeedUp.
  * Correctly handle nested comments.
  * Format lisp code correctly.
  * Correctly read the default style.
  * Gracefully handle invalid colors.
  * Changed the default communication port to 40100.
  * Several fixes for different combinations of wxWidgets and GTK
    versions.
  * Updated translations.
* Tue Jul 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 19.07.0
  * Many improvements and bugfixes in the LaTeX and HTML export
    function.
  * Many updated translations.
  * Resolved a freeze on autocompletion.
  * A sidebar that shows the contents of variables.
  * Simplified the recalculation logic in order to squash the
    remaining bugs.
  * Simplified the sync between input and output cells.
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com> - 19.05.7
- Update to version 19.05.7:
  * Support worksheets starting in a :lisp command [with maxima >=
    5.43.0]
* Fri May 10 2019 lars@linux-schulserver.de - 19.05.2
- Update to version 19.05.2:
  + Sometimes the auto-evaluation of the worksheet auto-triggered
  + Support for broken locales that for valid non-ascii chars returned
    isprint()= false
  + Corrected reading font sizes from styles and configuring styles.
* Tue Apr 23 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 19.04.3:
  + wxMaxima now informs maxima which front-end is in use.
* Tue Apr 16 2019 lars@linux-schulserver.de - 19.04.2
- update to version 19.04.2:
  + Corrected the size of error messages
  + A "Copy to mathlab"-feature.
  + Maxima now delays interpreting the data from maxima until it encounters
  + a newline or an Timer expires.
  + EMF output no no more causes crashes and strange behaviour.
  + RTF output should now work again
  + entermatrix() now works again.
  From 19.04.1:
  + Corrected the size of error messages.
  From 19.04.0:
  + The cursor width now is taken from the current screen
  + Autocompletion sometimes cleared the result after inputting it
  + Added more commands to autocompletion
  + Spanish and italian translation updates
  + We no more need to re-implement maxima's load() routine.
  + Instead we call the original one now.
  + Animations now on load remember which slide they stopped at.
  + A more error-proof language selection.
  + If the system looks like it uses UTF8 by default the locale name
  + that is passed to maxima now ends in ".UTF8" which should resolve
  + the "setting locale failed" errors from maxima.
  + Corrected the initial size of error messages.
  + Many additional bug fixes
  + Code cleanups
* Fri Mar 15 2019 Atri B <badshah400@gmail.com>
- Update to version 19.03.1
  * HighDPI fixes for ArchLinux, Windows and SuSE
  * Resolved crashes on RedHat and MS Windows
  * SBCL's compilation messages now appear in the status bar, not
    in the worksheet.
  * Removed an unneeded "maxima has finished calculating" on
    startup.
  * Many small bug fixes.
  * wxWidgets >= 3.1.0: Corrected the toolbar icon size.
* Fri Jan 25 2019 badshah400@gmail.com
- Update to version 19.01.2:
  * Corrected the size calculation for embedded images
  * Corrected the line widths for the printout
- Changes from version 19.01.1:
  * Sometimes the vertical size of maths was overestimated
  * Cmake now knows that we require wxWidgets >= 3.0
- Changes from version 19.01.0:
  * Many bugfixes for the display code
  * The desktop integration files now adher to the newest
    standards
  * Refactoring in order to make the code easier to understand.
  * Spelling fixes
  * Shipped around a wxWidgets <3.1 bug for embedding bitmaps in
    svg
  * Many Links were updated to https
  * A better help file detection that still works if there is no
    .hhp file.
- Drop custom desktop file and use updated upstream version.
- Adapt to upstream desktop and icon file name changes.
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 18.10.2:
  * Better cleanup on restarting Maxima.
  * Updated translations.
- Remove obsolete appdata directory from file-list: appdata is now
  installed to %%{_datadir}/metainfo.
* Sun Sep 30 2018 badshah400@gmail.com
- Update to version 18.10.1:
  * Corrected the version number wxMaxima identifies itself with.
- Changes from version 18.10.0:
  * Defer any try to change Maxima's configuration until all
    questions are answered.
  * A menu item that sets the autosubscript feature for the
    current worksheet.
  * A menu allowing to switch floats to engineering format.
  * Maxima can now pass the values of variables to wxMaxima.
  * Autocompletion for functions from lisp-only packages and for
    all of maxima's built in functions.
  * A context-sensitive "draw" sidepane.
  * We now allow a packet from Maxima to end in the middle of an
    unicode codepoint.
  * If the name of a lisp function is known it now is displayed.
  * A right-click menu that copies an animation to the clipboard.
  * A new default value for the current MathJaX release.
  * A "recent packages" menu for packages loaded from load() or
    from the menu.
  * Advertise the current file and the file's state to the
    Operating System
  * Copy as Enhanced Metafile (Windows only).
  * Code simplifications.
  * A dockable panel for the debug messages.
  * A more modern theme.
  * Draw: A right-click menu allowing to open images from the
    current session as interactive gnuplot sessions.
  * Migrate the config file to a XDG-compatible location if
    wxWidgets is new enough to support it.
  * A "Tip of the day" dialogue that allows for resizing,
    scrollbars and work while it is still open.
  * Matrices can now be displayed using round and square brackets.
  * Various High-DPI enhancements.
  * Enhancements for low-resolution screens.
  * Many bug fixes.
  * Reduced the number of autogenerated files, installed files and
    external dependencies to a minimum.
  * Big performance improvements, again.
- Update URL and Source urls in keeping with upstream changes.
* Wed May 16 2018 badshah400@gmail.com
- Drop Requires: libgnomeprint; it is not needed for printing any
  more.
* Wed Feb 21 2018 badshah400@gmail.com
- Update to version 18.02.0:
  * More tooltips
  * A menu containing the most important commands for lists.
  * TableOfContents: A right-click menu item that allows to toggle
    display of section numbers
  * The size of images can now be restricted to any amount of
    centimeters.
  * On a few operating systems: The network indicator icon now
    knows how much CPU power maxima uses.
  * Autocompletion now suggests the names of built-in packages for
    load(), batch(), and batchload().
  * Autocompletion now suggests the names of built-in demos for
    demo().
  * wxMaxima can now handle requests to display raw lisp elements.
  * A drop-down box for changing cell styles
  * If an input cell is hidden and has no output it now is no more
    displayed as a blank vertical space.
  * wxMaxima no more requires the icon files, tooltips and
    autocompletion files to be shipped as separate files, which
    makes creating a ready-to-install package of wxMaxima easier
    and less error-prone.
  * Autosave is now enabled by default on new installs.
  * Big code cleanups.
  * Many bugfixes
  * Many performance improvements
  * Dropped the autotools as the cmake build of wxMaxima is way
    more powerful.
- Drop unnecessary post[un] scriptlets for openSUSE >= 1500: these
  are automatically handled by rpm file-triggers.
* Thu Oct 26 2017 badshah400@gmail.com
- Update to version 17.10.1
  + No list of changes from upstream.
- Drop wxMaxima-fix-tooltip-comparison.patch: incorporated into
  upstream sources.
- Appdata is now installed to %%{_datadir}/metainfo, adapt file
  list accordingly. Own parent dir to avoid ownership issues.
* Thu Oct 12 2017 jengelh@inai.de
- Trim description of irrelevant parts.
* Wed Oct 11 2017 badshah400@gmail.com
- Update wxMaxima-fix-tooltip-comparison.patch to fix a potential
  crash introduced by its previous iteration; taken from upstream.
- Use rsvg-convert instead of inkscape to convert svg icons into
  multi-sized png icons -- this significantly reduces the number
  of build dependencies.
* Sun Oct  1 2017 badshah400@gmail.com
- Add wxMaxima-fix-tooltip-comparison.patch: Patch from upstream
  that fixes building by using the correct comparisn operations
  involving `tooltip` [gh#andrejv/wxmaxima#929].
* Sat Sep 30 2017 badshah400@gmail.com
- Update to version 17.10.0:
  * Jump to the char containing the error on encountering
    unmatched parenthesis.
  * Try to place the cursor near the error in all other cases.
  * Attempt to mark the whole error message in red. This is bound
    to fail in some cases as maxima sometimes only sends part of
    an error message through the error() command. But it is better
    than nothing.
  * Detect and mark most warnings.
  * A "evaluate cells below" right-click-menu item.
  * Autosave now even works for unsaved documents adding them to
    the "recent documents" list if needed.
  * Big parenthesis are now drawn using unicode characters, if
    available.
  * Nicer integral, Product and Sum signs, optionally including
    antialiassing even if no font provides them.
  * MouseOver tooltips for some of the more exotic worksheet
    items.
  * A "Copy as svg" function that is as good as wxSVGFileDc allows
    us to be.
  * Worksheet objects now can provide their own ToolTips.
  * Config Dialogue: An editor for the startup file.
  * It is now possible to select which formats "Ctrl+C" should
    place data on the clipboard in.
  * Now multiple animations can run concurrently and can be told
    to autostart.
  * A menu entry that allows to select 1D and ASCII Art Maths.
  * Recent files that currently don't exist are grayed out now.
  * A command-line switch that triggers evaluation on startup of
    wxMaxima.
  * Many Bug Fixes and Performance improvements.
* Sun Jul  9 2017 badshah400@gmail.com
- Update to version 17.05.1:
  * Mainly fixes some issues related to Mac OS
* Wed Jun 14 2017 badshah400@gmail.com
- Update to version 17.05.0:
  * A config item that allows to disable printing of Cell brackets
  * Cell brackets of inactive cells can now be hidden
  * Due to popular demand we can now suppress the output of
    automatic labels.
  * The option to use a Minus instead of a Hyphen.
  * Table of Contents: Folded items are now grayed out.
  * Table of Contents: A right-click menu.
  * Copy-and-paste now includes hidden cells and folded items.
  * Eye Candy: An indicator that shows when maxima and wxMaxima
    exchange data.
    Double-clicking this indicator opens up the network monitor.
  * Autocompletion now collects words from the current code cell,
    too.
  * Better indentation of if clauses and loops.
  * If the number is too long to display it now is still possible
    to copy it.
  * Documented that box() highlights text in maxima's output.
  * the with_slider type of commands now uses wxstatusbar() in
    order to provide progress information for the user.
  * Several scrolling fixes, again.
  * Two concurrent wxMaxima instances now no more overwrite each
    other's "Recent files" list.
  * If a error message or question arises or maxima finishes
    calculating and the window currently isn't active the
    operating system is asked to notify the user in a
    non-disrupting way. For the case of the end of a calculation
    this can be turned off.
  * The notification can be activated for the case that the window
    isn't active and maxima finishes calculating, too.
  * Invalid XML tags are now handled more gracefully
  * Deduplicated the code for saving .wxm files
  * content.xml files that have been extracted from a broken .wxmx
    file (e.G. using a text editor as UTF8-encoded TeXt without
    BOM can now be loaded by wxMaxima in order to reconstruct the
    worksheet.
  * MacOs: Upgrading from a previous version should no more cause
    crashes due to font issues.
  * MathJaX export can now be configured to instruct the html
    export to download MathJaX from a different URL: They moved
    the URL one can use and might do so again somewhere in the
    future.
  * Maximum number of digits and if we use user-defined labels now
    are no more hardcoded into the worksheet at evaluation time.
  * Anwers to maxima's questions are now remembered across
    sessions.
  * cmake is now our main build system
  * Massive speed-ups
  * File/Open can now import .mac and .out files from Xmaxima
  * Many additional bug fixes and stability enhancements.
- Switch to using cmake for build.
- Use github URL's for homepage and source tarball.
* Mon Mar 13 2017 tchvatal@suse.com
- Build with new RPM package in Factory
- Shorten a bit the description
- Remove unused configure switch
* Tue Feb  7 2017 badshah400@gmail.com
- Version update to 16.12.2:
  * Changes not documented by upstream.
- Changes from version 16.12.1:
  * Fixed a bug that broke the possibility to select output cells.
- Drop doc files already installed using %%doc.
* Mon Dec 19 2016 badshah400@gmail.com
- Version update to 16.12.0:
  * Not a change in wxMaxima, but useful: In maxima >5.38 the
    load() command can load .wxm files like it would load .mac
    files.
  * Better detection and diagnosis for maxima process that
    terminate unexpectedly even if the OS fails to notify us that
    the network connection with maxima has dropped.
  * Incremental search
  * Automatic line wrap
  * Bullet lists now use real bullets.
  * Markdown: Block quote support
  * A button that temporarily hides all code cells
  * Massive speedups in the drawing code.
  * Added a wxstatusbar() command that allows a long-ranging
    block() to send a string about its progress to the status bar.
  * Support for cells that are >5000 pixels wide
  * Better High-DPI support
  * A Kabyle Translation for users of wxWidgets >= 3.0.1
  * Holding the "evaluate" key now evaluates all cells of the
    document one-by-one
  * .wxm files now include image cells
  * Drag-and-drop now handles image cells
  * Copy bitmap now can generate higher-resolution bitmaps
  * The application we drag-and-drop to now can select a format to
    get the data in including RTF, MathML, wxm, bitmap and plain
    text.
  * A new "copy as plain text" right-click menu item that copies
    the input and output of a cell.
  * An all-new manual and improved documentation of the source
    code.
  * More unicode characters in the symbols pane
  * Several content assistent enhancements for platforms that
    support it.
  * Corrected a few scrolling bugs.
  * Shift+Click now selects text or cells.
  * Several small editor enhancements.
  * Even if we scrolled away from evaluation wxMaxima now scrolls
    back to the cell if an error occurs.
  * Integrals should now always be saved correctly.
  * Errors in xml from maxima or in the output cells of .wxmx
    files now result in error messages, not in silently discarded
    math elements.
  * Many additional bug fixes and performance improvements.
- Drop wxMaxima-appstream-xml-filename.patch, incorporated into
  upstream.
* Tue Aug  9 2016 tchvatal@suse.com
- Version update to 16.04.2:
  * various small bugfixes
- Sort with spec-cleaner
* Fri Jul 15 2016 badshah400@gmail.com
- Add wxMaxima-appstream-xml-filename.patch: Fix the appstream xml
  file name (must be identical to .desktop file name w/o ext) and
  the reference to the .desktop file therein (refers to
  wxmaxima.desktop while installing wxMaxima.desktop); reported
  upstream.
- Update file list accordingly:
  wxmaxima.appdata.xml -> wxMaxima.appdata.xml
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 16.04.1:
  + Bug fixes.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 16.04.0:
  + A TeX-like subscript notation: A_1 is now by default shown as
    an A with an 1 as subscript
  + High-quality icons for high-dpi screens.
  + Some broken .wxmx files generated with wxMaxima 13.04 and
    older will now automatically be repaired
  + Tried to make communication with maxima more stable
  + Debug: A monitor for the xml communication between maxima and
    wxMaxima
  + Leading White-space in front of a character that has to be
    escaped in XML is no more ignored.
  + jpeg-encoded images are now no more converted to much larger
    png files on saving .wxmx files and on exporting.
  + Images will now actually be converted to the target format.
  + Bumped the minor version of the .wxmx format: Some old
    versions of wxmaxima will replace .jpg files embedded in .wxmx
    files by a placeholder on load
  + Increased both speed and memory-efficiency of image handling
  + Save the zoom factor at exit and reload it on opening a new file
  + An option that makes wxMaxima use user-defined labels instead
    of %%o where an user-defined label exists. Works well together
    with unchecking the "export code cells" config item.
  + A separate text style for user-defined labels.
  + The "evaluate all cells" and "evaluate till here" now start
    with a fresh instance of maxima
  + TeX export now should work with most unicode chars we have ESC
    sequences for.
  + An auto-repair functionality that repairs most .wxmx files
    wxMaxima 13.04 was not able to open again.
  + A few new ESC sequences and markdown commands.
  + "#" now is shown as a "not equal" sign as a "not equal" sign
    already would be interpreted as "#".
  + Teach CCL on Windows how to deal with unicode variable names
    like ü and α. For SBCL the necessary change has been done on
    the maxima side.
  + Sidebars for symbols
  + Printing text cells now works again
  + The <ESC> key now works as a shortcut that closes the search
    dialogue.
  + A copy-to-MathML feature
  + Many bug, usability and performance fixes
  + Most importantly: If it is a cursor it now blinks.
- No longer rm .menu file, not bundled in upstream tarball any
  more.
* Mon Mar 28 2016 dvaleev@suse.com
- ExcludeArch POWER64 architecture, maxima is excluded due to missing
  clisp
* Tue Sep  8 2015 badshah400@gmail.com
- Update to version 15.08.2:
  - Bugs fixed:
    + Added en.po to distribution.
    + Disable check for event types.
    + Correctly update the stats sidebar visibility in menus.
    + Update version number.
    + Don't remove new lines from lisp cells.
    + Added en.mo to distrubution.
- Remove wxMaxima-missing-make-targets.patch: incorporated
  upstream.
* Thu Sep  3 2015 badshah400@gmail.com
- Update to version 15.08.1:
  + Bug fixes (undocumented).
- Rebase wxMaxima-missing-make-targets.patch; two issues fixed
  upstream (and removed from patch), one issue persists.
* Wed Aug 19 2015 badshah400@gmail.com
- Update to version 15.08.0:
  + MathJAX now provides scaleable equations and extended
    drag-and-drop for the html export.
  + The table-of-contents-sidebar now shows the current cursor
    position.
  + Fixed a few instances of cursors jumping out of the screen.
  + Fixed a few instances of cursors jumping to the beginning or
    end of the worksheet.
  + Better detection which cell maxima is processing and if it
    still is doing so.
  + Regression: Hiding the toolbar didn't work on some systems.
  + Markdown support for <=, >=, <=>, <-, ->, <->, => and +/-
    symbols.
  + An option to not export maxima's input as well as the output.
  + An option to use High-resolution bitmaps for the HTML export.
  + Images that are too big for the window now are displayed in a
    scaled-down version.
  + Fixed the support for out-of-tree-bulds that was broken in 15.04.
  + Meaningful ALT texts for the HTML export to provide accessibility.
  + An option to include the .wxmx file in the .html export.
  + Performance fixes that are espectionally effective for MSW
  + Unification of some platform-specific code.
  * bash autocompletion.
  + A fourth sectioning level.
  + Made entering uppercase greek letters easier and documented
    how to input special unicode symbols.
  + Syntax highlighting in code cells.
  + Automatic highlighting of text equal to the currrently
    selected one.
  + A batch mode that pauses evaluation if maxima asks a question.
  + A "halt on error" feature.
  + Now evaluation of a new command is only triggered if
    evaluation of the last command has finished. This means that
    output from maxima is always appended to the right cell.
  + Un-broke error and question handling for multiple commands per
    cell. Sincewe now send maxima's input command-per-command this
    means a cell with multiple commands is no more evaluated
    faster than multiple cells with single commands each.
  + If ever a end-of-evaluation marker gets lost there is a new
    "trigger evaluation" menu entry in the maxima menu.
  + On wxGtk autocompletion was replaced by a content assistant
    that is based on the surprisingly powerful autocompletion
    feature.
  + Ctrl+Tab now launches the autocompletion (or content
    assistant, if available).
  + Tab and Shift+Tab now indent and unindent regions.
  + Ctrl+Mouse wheel and Ctrl++/- now zoom in and out of the
    worksheet.
  + Allow Extending selection from part of a single cell to
    multiple cells.
  + An Autoindent functionality.
- Changes from version 15.04.0:
  + See /usr/doc/packages/wxMaxima/ChangeLog file.
- Explicit dependency on wxwidgets >= 3.0.
- Update maxima version required for building.
- Package ChangeLog file available in upstream tarball since
  version 15.04.0.
- Add patch required because upstream missed a few files from
  the tarball:
  + wxMaxima-missing-make-targets.patch (touches autotool files
    BR on autoreconf required).
- Generate and install hicolor icons from the bundled svg icon
  file; introduces BR on inkscape, hicolor-icon-theme.
- Use %%post and %%postun scriptlets as necessary.
- Update filelist to include new files installed by upstream, as
  well as hicolor icons.
- Update desktop menu filename to be consistent with upstream; add
  Mimetypes specification to .desktop file.
* Mon Feb  9 2015 jengelh@inai.de
- Use wxWidgets 3 and remove manual dependencies.
  Run fdupes over more files.
* Thu Dec 25 2014 badshah400@gmail.com
- Update to version 14.12.1:
  + No documentation of changes.
- Changes from version 14.12.0:
  + No documentation of changes.
* Wed Sep 17 2014 badshah400@gmail.com
- Update to verson 14.09.0:
  + No detailed changelog available
- Packaging changes:
  + Adapt to source tarball name change from wxMaxima to wxmaxima
  + Add rpmlintrc file as source.
* Sat May 25 2013 badshah400@gmail.com
- Update to version 13.04.2:
  + Fix a bug with matchParens=false option
- Changes from version 13.04.1:
  + Include all files in the source tgz
- Drop wxMaxima-fix-missing-locale.patch; upstream now includes
  all required source files, making patch unnecessary.
* Tue Apr 23 2013 badshah400@gmail.com
- Update to version 13.04.0:
  + No detailed changelog available
- Add wxMaxima-fix-missing-locale.patch to fix build failure while
  trying to install a locale that is missing from the tarball.
* Tue Sep 11 2012 badshah400@gmail.com
- Update to version 12.09.0:
  + No detailed changelog available
- Change source url in spec file.
* Sat May 19 2012 badshah400@gmail.com
- Update to version 12.04:
  + No detailed changelog available.
- Spec file cleanups:
  + Correct License tag in keeping with spdx.org recommendations
  + Use fdupes to link duplicate files
* Sun Sep 18 2011 lars@linux-schulserver.de
- update to 11.08.0
* Thu Mar 17 2011 sbrabec@suse.cz
- Compile with wxcontainer variant, binary linked with STL crashes.
  https://sourceforge.net/projects/wxmaxima/forums/forum/435775/topic/4410333
* Mon Mar  7 2011 sbrabec@suse.cz
- Compile with openSUSE wxWidgets (default variant).
- Remove BuildRequires: libstdc++ that is no more provided.
* Sun Mar  6 2011 lars@linux-schulserver.de
- update to 0.8.7
* Sun Sep 19 2010 werner.ho@gmx.de
- updated to version 8.6
* Sun Nov 22 2009 lars@linux-schulserver.de
- removed "--disable-statix-wx" as it looks like this triggers an
  error "Maxima process terminated" in the status bar, even though
  Maxima runs fine either by itself or through xMaxima.
  (Thanks to Moby for reporting the issue!)
* Mon Sep 21 2009 lars@linux-schulserver.de
- update to 0.8.3a
* Sat Apr 25 2009 lars@linux-schulserver.de
- update to 0.8.2:
  + new wxMaxima document format (not compatible with .wxm) which
    saves maxima output and inline plots into a single file (you
    can still save and load ".wxm" format, but you don't get the
    improvements of the new one)
  + images can be inserted into the document
  + when input is modified after evaluation, output becomes gray to
    indicate it is no longer up to date
  + styles section improved: colors can be set for all elements of
    wxmaxima document, title, section and text cells can have a
    different font, support for loading/saving styles into a file
  + "Open Recent" added to the file menu
  + "unix copy" (copy on select) now working as expected
    (selection copies, middle mouse click pastes) option to use
    evaluate with enter instead of shift-enter
  + full screen mode (alt + enter)
  + backspace and delete keys can be used for deleting cells when
    horizontal cursor is active
  + Bugfix: Restart Maxima doesn't clear the document
  + Bugfix: reduced the number of redraws - the GUI feels a bit snappier
  + Bugfix: Opening a WXM file doesn't automaticly restart Maxima
- removed obsolete --enable-dnd
- cleanup specfile
* Fri Dec 19 2008 lars@linux-schulserver.de
- update to 0.8.1:
  + bugfix: set horizontal cursor after Maxima header when starting
    wxMaxima
  + bugfix: when horizontal cursor is active keys like left, right,
    page up/down, home/end don't insert a new input cell
  + new feature: optional, display center dot instead of *
* Fri Dec  5 2008 lars@linux-schulserver.de
- update to 0.8.0:
  + wxMaxima document now made of 'cells'
  + cells can be evaluated with SHIFT-ENTER
  + long Maxima outputs can be hidden by clicking into the triangle
    at the top of that cell's left bracket
  + reorganised some menus
  + cells can now be edited by single-click
  + if you have a selection of text/code, ([{ will put ([{}]) around
    selection and place cursor before first ([{, pressing }]) will put
    the cursor after the last }])
  + double clicking will select the word under the cursor
  + double clicking on (,[,{ or },],) will select the text/code between ([{ }])
  + F1 now selects the word under cursor if there's no selection, and
    searches help for that word
  + removed the INPUT line
  + introduced a 'horizontal cursor': click between cells to set it,
    start typing to insert a new input cell, press F6 to insert a new
    text cell, SHIT-UP/DOWN or click'n'drag selects cells
  + Maxima questions answered in the document - a cursor should appear,
    SHIFT-ENTER sends your answer to Maxima. If a cursor doesn't appear,
    click below the cell, type the answer and press SHIFT-ENTER
* Wed Oct  8 2008 lars@linux-schulserver.de
- own %%_datadir/wxMaxima
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Fri Aug 22 2008 lars@linux-schulserver.de
- update to 0.7.6
- build also on fedora
* Sun May 25 2008 lars@linux-schulserver.de
- disable gnuplot patch for now (os-edu #0000039)
* Mon Apr 21 2008 lars@linux-schulserver.de
- update to 0.7.5:
  + part of wxMaxima-ATTRIBUTE_PRINTF.patch is upstream:
  - > wxMaxima-0.7.5-ATTRIBUTE_PRINTF.patch
  + don't try to use outdated gnuplot:
  wxMaxima-0.7.5-old_gnuplot.patch
- updated desktop file (added german description)
* Sun Feb  3 2008 kirill.kirillov@gmail.com
- fix gnuplot requires
* Mon Dec 10 2007 lars@linux-schulserver.de
- update to version 0.7.4
- combine the patches wxMaxima-MathParser.cpp.diff and
  wxMaxima-MathParser.h.diff in wxMaxima-ATTRIBUTE_PRINTF.patch
- enable unicode-glyphs
- enable printing
- Enable drag'n'drop support
* Fri Sep  7 2007 Werner Hoch <werner.ho@gmx.de>
- updated to version 0.7.3
* Thu May 17 2007 Werner Hoch <werner.ho@gmx.de>
- updated to version 0.7.2
* Fri Feb  2 2007 Werner Hoch <werner.ho@gmx.de>
- updated to version 0.7.1
- added ATTRIBUTE_PRINTF patches
* Sun Aug 13 2006 Leon Freitag <leon@links2linux.de>
- initial release for BS
- minor corrections to make the prefix relocatable
- update the group to be compatible with the SPC
* Tue Dec 14 2004 Andrej Vodopivec <andrejv@users.sourceforge.net>
- Added french translation files.
* Tue Aug 24 2004 Andrej Vodopivec <andrejv@users.sourceforge.net>
- Initial spec file.
